==> rmcfs_1.1.2.tar.gz: rmcfs/java/src/dmLab/mcfs/mcfsEngine/framework/MCFSClassic.java <==
/*******************************************************************************
 * #-------------------------------------------------------------------------------
 * # Copyright (c) 2003-2016 IPI PAN.
 * # All rights reserved. This program and the accompanying materials
 * # are made available under the terms of the GNU Public License v3.0
 * # which accompanies this distribution, and is available at
 * # http://www.gnu.org/licenses/gpl.html
 * # 
 * #-------------------------------------------------------------------------------
 * # @description: data mining (dmLab) library that implements MCFS-ID algorithm
 * # @author: Michal Draminski [mdramins@ipipan.waw.pl]
 * # @company: Polish Academy of Sciences - Institute of Computer Science
 * # @homepage: http://www.ipipan.eu/
 * #-------------------------------------------------------------------------------
 * # Algorithm 'SLIQ' developed by Mariusz Gromada
 * # R Package developed by Michal Draminski & Julian Zubek
 * #-------------------------------------------------------------------------------
 * # If you want to use dmLab or MCFS/MCFS-ID, please cite the following paper:
 * # M.Draminski, A.Rada-Iglesias, S.Enroth, C.Wadelius, J. Koronacki, J.Komorowski 
 * # "Monte Carlo feature selection for supervised classification", 
 * # BIOINFORMATICS 24(1): 110-117 (2008)
 * #-------------------------------------------------------------------------------
 *******************************************************************************/
package dmLab.mcfs.mcfsEngine.framework;

import java.util.Random;

public class MCFSClassic extends MCFSFramework implements Runnable 
{
	//*************************************
	public MCFSClassic(Random random) {
		super(random);
	}
	//*************************************
	@Override
	public void run()
	{   
		saveResutFiles = true;
		experimentName = mcfsParams.getExperimentName();

		System.out.println("***************************");
		System.out.println("***       MCFS-ID       ***");
		System.out.println("***************************");        

		runExperiment(mcfsArrays.sourceArray);

		return;        
	}
	//	*************************************
}

==> rmcfs_1.2.5.tar.gz: rmcfs/java/src/dmLab/mcfs/mcfsEngine/framework/MCFSClassic.java <==
/*******************************************************************************
 * #-------------------------------------------------------------------------------
 * # Copyright (c) 2003-2016 IPI PAN.
 * # All rights reserved. This program and the accompanying materials
 * # are made available under the terms of the GNU Public License v3.0
 * # which accompanies this distribution, and is available at
 * # http://www.gnu.org/licenses/gpl.html
 * # 
 * #-------------------------------------------------------------------------------
 * # @description: data mining (dmLab) library that implements MCFS-ID algorithm
 * # @author: Michal Draminski [mdramins@ipipan.waw.pl]
 * # @company: Polish Academy of Sciences - Institute of Computer Science
 * # @homepage: http://www.ipipan.eu/
 * #-------------------------------------------------------------------------------
 * # Algorithm 'SLIQ' developed by Mariusz Gromada
 * # R Package developed by Michal Draminski & Julian Zubek
 * #-------------------------------------------------------------------------------
 * # If you want to use dmLab or MCFS/MCFS-ID, please cite the following paper:
 * # M.Draminski, A.Rada-Iglesias, S.Enroth, C.Wadelius, J. Koronacki, J.Komorowski 
 * # "Monte Carlo feature selection for supervised classification", 
 * # BIOINFORMATICS 24(1): 110-117 (2008)
 * #-------------------------------------------------------------------------------
 *******************************************************************************/
package dmLab.mcfs.mcfsEngine.framework;

import java.util.Random;

public class MCFSClassic extends MCFSFramework implements Runnable 
{
	//*************************************
	public MCFSClassic(Random random) {
		super(random);
	}
	//*************************************
	@Override
	public void run()
	{   
		experimentName = mcfsParams.getExperimentName();
		//System.out.println("*** MCFS-ID ***");
		runExperiment(mcfsArrays.sourceArray);

		return;        
	}
	//	*************************************
}
